package
Version:
v0.0.0-...-344e952
Opens a new window with list of versions in this module.
Published: Apr 30, 2021
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Start_Processor(tc_name string)
type CSV_To_MySQL struct {
Processor_name string
Source struct {
Source_type string
Source_location string
}
Processor struct {
Processor_name string
}
Target struct {
Target_type string
Database_name string
Table_name string
}
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.